@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2007-2020 The Octave Project Developers
+// Copyright (C) 2007-2024 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -38,7 +38,7 @@ public:
   typedef std::string::iterator iterator;
   typedef std::string::const_iterator const_iterator;
 
-  caseless_str (void) = default;
+  caseless_str () = default;
 
   caseless_str (const std::string& s) : std::string (s) { }
   caseless_str (const char *s) : std::string (s) { }
@@ -47,7 +47,7 @@ public:
 
   caseless_str& operator = (const caseless_str&) = default;
 
-  ~caseless_str (void) = default;
+  ~caseless_str () = default;
 
   bool operator < (const std::string& s) const
   {
@@ -75,12 +75,12 @@ public:
   }
 
   // Case-insensitive comparison.
-  bool compare (const std::string& s, size_t limit = std::string::npos) const
+  bool compare (const std::string& s, std::size_t limit = std::string::npos) const
   {
     auto p1 = begin ();
     auto p2 = s.begin ();
 
-    size_t k = 0;
+    std::size_t k = 0;
 
     while (p1 != end () && p2 != s.end () && k++ < limit)
       {
