@@ -1,20 +1,27 @@
-## Copyright (C) 2016-2017 Markus Muetzel
+########################################################################
+##
+## Copyright (C) 2016-2024 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} light ()
@@ -26,13 +33,15 @@
 ## When a light object is present in an axes object, and the properties
 ## @qcode{"EdgeLighting"} or @qcode{"FaceLighting"} of a @code{patch} or
 ## @code{surface} object are set to a value other than @qcode{"none"}, these
-## objects are drawn with light and shadow effects.  Supported values for
-## Lighting properties are @qcode{"none"} (no lighting effects), @qcode{"flat"}
-## (faceted look of the objects), and @qcode{"gouraud"} (linear interpolation
-## of the lighting effects between the vertices).  For @code{patch} objects,
-## the normals must be set manually (property @qcode{"VertexNormals"}).
+## objects are drawn with lighting effects.  Supported values for Lighting
+## properties are @qcode{"none"} (no lighting effects), @qcode{"flat"} (faceted
+## look of the objects), and @qcode{"gouraud"} (linear interpolation of the
+## lighting effects between the vertices).  If the lighting mode is set to
+## @qcode{"flat"}, the @qcode{"FaceNormals"} property is used for lighting.
+## For @qcode{"gouraud"}, the @qcode{"VertexNormals"} property is used.
 ##
-## Up to eight light objects are supported per axes.
+## Up to eight light objects are supported per axes.  (Implementation
+## dependent)
 ##
 ## Lighting is only supported for OpenGL graphic toolkits (i.e., @qcode{"fltk"}
 ## and @qcode{"qt"}).
@@ -59,11 +68,11 @@
 ## The optional return value @var{h} is a graphics handle to the created light
 ## object.
 ##
+## Programming Note: The full list of properties is documented at
+## @ref{Light Properties}.
 ## @seealso{lighting, material, patch, surface}
 ## @end deftypefn
 
-## Author: mmuetzel
-
 function h = light (varargin)
 
   [hax, varargin] = __plt_get_axis_arg__ ("light", varargin{:});
@@ -88,43 +97,43 @@ endfunction
 %! clf;
 %! ## patches
 %! h_axes1 = subplot (2, 2, 1);
-%! [x,y,z] = meshgrid (-2:0.2:2, -2:0.2:2, -2:0.2:2);
-%! val = x.^2 + y.^2 + z.^2;
-%! fv1 = isosurface (x, y, z, val, 1);
-%! h_patch1 = patch (fv1, "FaceColor", "c", "EdgeColor", "none", ...
-%!                        "FaceLighting", "Gouraud");
-%! isonormals (x, y, z, val, h_patch1);
-%! fv2 = isosurface (x, y+3, z, val, 1);
-%! h_patch2 = patch (fv2, "FaceColor", "r", "EdgeColor", "none", ...
-%!                        "FaceLighting", "Gouraud");
-%! isonormals (x, y+3, z, val, h_patch2);
-%! axis equal; axis tight
-%! title ("Patch with lighting");
-%! view (3);
-%! h_light1 = light ();
+%!  [x,y,z] = meshgrid (-2:0.2:2, -2:0.2:2, -2:0.2:2);
+%!  val = x.^2 + y.^2 + z.^2;
+%!  fv1 = isosurface (x, y, z, val, 1);
+%!  h_patch1 = patch (fv1, "FaceColor", "c", "EdgeColor", "none", ...
+%!                         "FaceLighting", "Gouraud");
+%!  isonormals (x, y, z, val, h_patch1);
+%!  fv2 = isosurface (x, y+3, z, val, 1);
+%!  h_patch2 = patch (fv2, "FaceColor", "r", "EdgeColor", "none", ...
+%!                         "FaceLighting", "Gouraud");
+%!  isonormals (x, y+3, z, val, h_patch2);
+%!  view (3);
+%!  axis equal;  axis tight;
+%!  title ("Patch with lighting");
+%!  h_light1 = light ();
 %!
 %! h_axes2 = subplot (2, 2, 2);
-%! patch (fv1, "FaceColor", "c", "EdgeColor", "none");
-%! patch (fv2, "FaceColor", "r", "EdgeColor", "none");
-%! axis equal; axis tight
-%! title ("Patch without lighting");
-%! view (3);
+%!  patch (fv1, "FaceColor", "c", "EdgeColor", "none");
+%!  patch (fv2, "FaceColor", "r", "EdgeColor", "none");
+%!  view (3);
+%!  axis equal;  axis tight;
+%!  title ("Patch without lighting");
 %!
 %! ## surfaces
 %! h_axes3 = subplot (2, 2, 3);
-%! h_surf1 = surf (h_axes3, peaks, "LineStyle", "none", ...
-%!                                 "FaceLighting", "Gouraud");
-%! title ("Surface with lighting");
-%! view (3);
-%! h_light2 = light ();
+%!  h_surf1 = surf (h_axes3, peaks, "LineStyle", "none", ...
+%!                                  "FaceLighting", "Gouraud");
+%!  title ("Surface with lighting");
+%!  view (3);
+%!  h_light2 = light ();
 %!
 %! h_axes3 = subplot (2, 2, 4);
-%! h_surf2 = surf (h_axes3, peaks, "LineStyle", "none");
-%! title ("Surface without lighting");
-%! view (3);
+%!  h_surf2 = surf (h_axes3, peaks, "LineStyle", "none");
+%!  view (3);
+%!  title ("Surface without lighting");
 
 %!demo
-%! ## Lighting modes
+%! ## Lighting modes on patches
 %! clf;
 %! [x,y,z] = meshgrid (-.2:0.05:.2, -.2:0.05:.2, -.2:0.05:.2);
 %! val = (x.^2 + y.^2 + z.^2);
@@ -133,52 +142,69 @@ endfunction
 %! fv = isosurface (x, y, z, val, .039);
 %! h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
 %!                      "FaceLighting", "none");
-%! isonormals (x, y, z, val, h_patch);
 %! fv = isosurface (x+.5, y, z, val, .039);
 %! h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
 %!                      "FaceLighting", "flat");
-%! isonormals (x+.5, y, z, val, h_patch)
 %! fv = isosurface (x+1, y, z, val, .039);
 %! h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
 %!                      "FaceLighting", "Gouraud");
-%! isonormals (x+1, y, z, val, h_patch);
 %! axis tight
 %! axis equal
 %! view (2);
 %! light ("Position", [-1 1 1]);
-%! title ({"FaceLighting", "none - flat - gouraud"});
+%! title ({"FaceLighting on patches", "none - flat - gouraud"});
+
+%!demo
+%! ## Lighting modes on surfaces
+%! clf;
+%! Z = peaks ();
+%! [X, Y] = meshgrid (1:columns (Z), 1:rows (Z));
+%!
+%! h_axes1 = axes ();
+%! surf (X, Y, Z, "LineStyle", "none", "FaceLighting", "none");
+%! hold on;
+%! surf (X + round (1.2 * columns (Z)), Y, Z, "LineStyle", "none", ...
+%!       "FaceLighting", "flat");
+%! surf (X + round (2.4 * columns (Z)), Y, Z, "LineStyle", "none", ...
+%!       "FaceLighting", "gouraud");
+%! axis tight
+%! axis equal
+%! view (2);
+%! light ("Position", [-1 1 1]);
+%! title ({"FaceLighting on surfaces", "none - flat - gouraud"});
 
 %!demo
 %! ## multiple lights
 %! clf;
 %! h_axes = subplot (1, 2, 1);
-%! [x,y,z] = meshgrid (-2:0.1:2, -2:0.1:2, -2:0.1:2);
-%! val = x.^2 + y.^2 + z.^2;
-%! fv = isosurface (x, y, z, val, 1);
-%! h_patch = patch (fv, "FaceColor", "w", "EdgeColor", "none", ...
-%!                      "FaceLighting", "Gouraud");
-%! isonormals (x, y, z, val, h_patch);
-%! axis equal; axis tight
-%! title ("Patch with one light");
-%! view (3);
-%! h_light = light ("Color", "g");
+%!  [x,y,z] = meshgrid (-2:0.1:2, -2:0.1:2, -2:0.1:2);
+%!  val = x.^2 + y.^2 + z.^2;
+%!  fv = isosurface (x, y, z, val, 1);
+%!  h_patch = patch (fv, "FaceColor", "w", "EdgeColor", "none", ...
+%!                       "FaceLighting", "Gouraud");
+%!  isonormals (x, y, z, val, h_patch);
+%!  view (3);
+%!  axis equal;  axis tight;
+%!  title ("Patch with one light");
+%!  h_light = light ("Color", "g");
 %!
 %! h_axes2 = subplot (1, 2, 2);
-%! h_patch2 = patch (fv, "FaceColor", "w", "EdgeColor", "none", ...
-%!                       "FaceLighting", "Gouraud");
-%! isonormals (x, y, z, val, h_patch2);
-%! axis equal; axis tight
-%! title ("Patch with three lights");
-%! view (3);
-%! h_light1 = light ("Color", "r");
-%! h_light2 = light ("Position", [0 1 1], "Color", "b");
-%! h_light3 = light ("Position", [-1 -1 2], "Color", "g");
+%!  h_patch2 = patch (fv, "FaceColor", "w", "EdgeColor", "none", ...
+%!                        "FaceLighting", "Gouraud");
+%!  isonormals (x, y, z, val, h_patch2);
+%!  view (3);
+%!  axis equal;  axis tight;
+%!  title ("Patch with three lights");
+%!  h_light1 = light ("Color", "r");
+%!  h_light2 = light ("Position", [0 1 1], "Color", "b");
+%!  h_light3 = light ("Position", [-1 -1 2], "Color", "g");
 
 %!demo
 %! ## Diffuse and specular reflection
 %! clf;
 %! h_axes = axes ();
-%! [x,y,z] = meshgrid (-.2:0.04:.2, -.2:0.04:.2, -.2:0.04:.2);
+%! rng = linspace (-0.2, +0.2, 12);
+%! [x,y,z] = meshgrid (rng);
 %! val = (x.^2 + y.^2 + z.^2);
 %!
 %! fv = isosurface (x, y, z, val, .039);
@@ -229,9 +255,9 @@ endfunction
 %! set (h_patch, "DiffuseStrength", 1, "SpecularStrength", 1);
 %! isonormals (x+1, y+1, z, val, h_patch);
 %!
+%! view (2);
 %! axis equal
 %! h_light = light ("Position", [-1 1 1]);
-%! view (2);
 %!
 %! xlabel ("SpecularStrength");
 %! ylabel ("DiffuseStrength");
@@ -244,75 +270,75 @@ endfunction
 %! val = (x.^2 + y.^2 + z.^2);
 %!
 %! h_axes1 = subplot (3,1,3);
-%! set (h_axes1, "AmbientLightColor", "g");
-%! fv = isosurface (x, y, z, val, .039);
-%! h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
-%!                      "FaceLighting", "Gouraud");
-%! set (h_patch, "AmbientStrength", 0);
-%! isonormals (x, y, z, val, h_patch);
-%! fv = isosurface (x+.5, y, z, val, .039);
-%! h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
-%!                      "FaceLighting", "Gouraud");
-%! set (h_patch, "AmbientStrength", .7);
-%! isonormals (x+.5, y, z, val, h_patch);
-%! fv = isosurface (x+1, y, z, val, .039);
-%! h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
-%!                      "FaceLighting", "Gouraud");
-%! set (h_patch, "AmbientStrength", 1);
-%! isonormals (x+1, y, z, val, h_patch);
-%! h_light = light ("Position", [-1 1 1]);
-%! axis tight
-%! axis equal
-%! view (2);
-%! xlabel ("AmbientStrength");
-%! ylabel ({"AmbientLightColor", "[0 1 0]"});
+%!  set (h_axes1, "AmbientLightColor", "g");
+%!  fv = isosurface (x, y, z, val, .039);
+%!  h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
+%!                       "FaceLighting", "Gouraud");
+%!  set (h_patch, "AmbientStrength", 0);
+%!  isonormals (x, y, z, val, h_patch);
+%!  fv = isosurface (x+.5, y, z, val, .039);
+%!  h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
+%!                       "FaceLighting", "Gouraud");
+%!  set (h_patch, "AmbientStrength", .7);
+%!  isonormals (x+.5, y, z, val, h_patch);
+%!  fv = isosurface (x+1, y, z, val, .039);
+%!  h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
+%!                       "FaceLighting", "Gouraud");
+%!  set (h_patch, "AmbientStrength", 1);
+%!  isonormals (x+1, y, z, val, h_patch);
+%!  h_light = light ("Position", [-1 1 1]);
+%!  view (2);
+%!  axis tight
+%!  axis equal
+%!  xlabel ("AmbientStrength");
+%!  ylabel ({"AmbientLightColor", "[0 1 0]"});
 %!
 %! h_axes2 = subplot (3,1,2);
-%! set (h_axes2, "AmbientLightColor", [.5 0 1]);
-%! fv = isosurface (x, y, z, val, .039);
-%! h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
-%!                      "FaceLighting", "Gouraud");
-%! set (h_patch, "AmbientStrength", 0);
-%! isonormals (x, y, z, val, h_patch);
-%! fv = isosurface (x+.5, y, z, val, .039);
-%! h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
-%!                      "FaceLighting", "Gouraud");
-%! set (h_patch, "AmbientStrength", .7);
-%! isonormals (x+.5, y, z, val, h_patch);
-%! fv = isosurface (x+1, y, z, val, .039);
-%! h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
-%!                      "FaceLighting", "Gouraud");
-%! set (h_patch, "AmbientStrength", 1);
-%! isonormals (x+1, y, z, val, h_patch);
-%! h_light = light ("Position", [-1 1 1]);
-%! axis tight
-%! axis equal
-%! view (2);
-%! ylabel ({"AmbientLightColor", "[.5 0 1]"});
+%!  set (h_axes2, "AmbientLightColor", [.5 0 1]);
+%!  fv = isosurface (x, y, z, val, .039);
+%!  h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
+%!                       "FaceLighting", "Gouraud");
+%!  set (h_patch, "AmbientStrength", 0);
+%!  isonormals (x, y, z, val, h_patch);
+%!  fv = isosurface (x+.5, y, z, val, .039);
+%!  h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
+%!                       "FaceLighting", "Gouraud");
+%!  set (h_patch, "AmbientStrength", .7);
+%!  isonormals (x+.5, y, z, val, h_patch);
+%!  fv = isosurface (x+1, y, z, val, .039);
+%!  h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
+%!                       "FaceLighting", "Gouraud");
+%!  set (h_patch, "AmbientStrength", 1);
+%!  isonormals (x+1, y, z, val, h_patch);
+%!  h_light = light ("Position", [-1 1 1]);
+%!  view (2);
+%!  axis tight
+%!  axis equal
+%!  ylabel ({"AmbientLightColor", "[.5 0 1]"});
 %!
 %! h_axes3 = subplot (3,1,1);
-%! set (h_axes3, "AmbientLightColor", "w");
-%! fv = isosurface (x, y, z, val, .039);
-%! h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
-%!                      "FaceLighting", "Gouraud");
-%! set (h_patch, "AmbientStrength", 0);
-%! isonormals (x, y, z, val, h_patch);
-%! fv = isosurface (x+.5, y, z, val, .039);
-%! h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
-%!                      "FaceLighting", "Gouraud");
-%! set (h_patch, "AmbientStrength", .7);
-%! isonormals (x+.5, y, z, val, h_patch);
-%! fv = isosurface (x+1, y, z, val, .039);
-%! h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
-%!                      "FaceLighting", "Gouraud");
-%! set (h_patch, "AmbientStrength", 1);
-%! isonormals (x+1, y, z, val, h_patch);
-%! h_light = light ("Position", [-1 1 1]);
-%! axis tight
-%! axis equal
-%! view (2);
-%! ylabel ({"AmbientLightColor", "[1 1 1]"});
-%! title ("Effects of AmbientLightColor and AmbientStrength");
+%!  set (h_axes3, "AmbientLightColor", "w");
+%!  fv = isosurface (x, y, z, val, .039);
+%!  h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
+%!                       "FaceLighting", "Gouraud");
+%!  set (h_patch, "AmbientStrength", 0);
+%!  isonormals (x, y, z, val, h_patch);
+%!  fv = isosurface (x+.5, y, z, val, .039);
+%!  h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
+%!                       "FaceLighting", "Gouraud");
+%!  set (h_patch, "AmbientStrength", .7);
+%!  isonormals (x+.5, y, z, val, h_patch);
+%!  fv = isosurface (x+1, y, z, val, .039);
+%!  h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
+%!                       "FaceLighting", "Gouraud");
+%!  set (h_patch, "AmbientStrength", 1);
+%!  isonormals (x+1, y, z, val, h_patch);
+%!  h_light = light ("Position", [-1 1 1]);
+%!  view (2);
+%!  axis tight
+%!  axis equal
+%!  ylabel ({"AmbientLightColor", "[1 1 1]"});
+%!  title ("Effects of AmbientLightColor and AmbientStrength");
 
 %!demo
 %! ## Specular Exponent
@@ -337,9 +363,9 @@ endfunction
 %! set (h_patch, "SpecularExponent", 1);
 %! isonormals (x+1, y, z, val, h_patch);
 %! h_light = light ("Position", [-1 1 1]);
+%! view (2);
 %! axis tight
 %! axis equal
-%! view (2);
 %! xlabel ("SpecularExponent");
 %! title ("Effects of SpecularExponent");
 
@@ -365,15 +391,16 @@ endfunction
 %!                      "FaceLighting", "Gouraud");
 %! set (h_patch, "SpecularColorReflectance", 1);
 %! isonormals (x+1, y, z, val, h_patch);
+%! view (2);
 %! h_light = light ("Position", [-1 1 1]);
 %! axis tight
 %! axis equal
-%! view (2);
 %! xlabel ("SpecularColorReflectance");
 %! title ("Effects of SpecularColorReflectance");
 
 %!demo
 %! ## BackFaceLighting
+%! clf;
 %! [x,y,z] = meshgrid (-.5:0.1:2, -2:0.1:2, -2:0.1:2);
 %! val = x.^2 + y.^2 + z.^2;
 %! fv = isosurface (x, y, z, val, 1);
@@ -393,8 +420,8 @@ endfunction
 %! set (h_patch, "BackFaceLighting", "lit");
 %! h_light = light ();
 %! view (h_axes2, [-50 30]);
-%! title ("lit");
 %! axis equal
+%! title ("lit");
 %!
 %! h_axes3 = subplot (1, 3, 3);
 %! h_patch = patch (fv, "FaceColor", "c", "EdgeColor", "none", ...
@@ -402,12 +429,13 @@ endfunction
 %! set (h_patch, "BackFaceLighting", "unlit");
 %! h_light = light ();
 %! view (h_axes3, [-50 30]);
-%! title ("unlit");
 %! axis equal
+%! title ("unlit");
 
 %!demo
 %! ## BackFaceLighting 2
 %! ## Matlab fails for "reverselit" with negated isonormals and for "unlit"
+%! clf;
 %! N = 30; iso = .8;
 %! lin = linspace (-1, 1, N);
 %! [x, y, z] = meshgrid (1.2*lin, 1.2*lin, lin);
@@ -416,60 +444,59 @@ endfunction
 %! fv = isosurface (x, y, z, val, iso);
 %! vn = isonormals (x, y, z, val, fv.vertices);
 %!
-%! clf;
 %! subplot (2, 3, 1);
-%! view (140, 20);
-%! axis equal
-%! hp = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
-%!             "BackFaceLighting", "reverselit", "VertexNormals", -vn);
-%! hl = light ("Position", [1 0 .5]);
-%! lighting gouraud
-%! title ({"BackFaceLighting", '"reverselit"', 'isonormals(...,"negate")'});
+%!  view (140, 20);
+%!  axis equal
+%!  hp = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
+%!              "BackFaceLighting", "reverselit", "VertexNormals", -vn);
+%!  hl = light ("Position", [1 0 .5]);
+%!  lighting gouraud
+%!  title ({"BackFaceLighting", '"reverselit"', 'isonormals(...,"negate")'});
 %!
 %! subplot (2, 3, 2);
-%! view (140, 20);
-%! axis equal
-%! hp = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
-%!             "BackFaceLighting", "lit", "VertexNormals", -vn);
-%! hl = light ("Position", [1 0 .5]);
-%! lighting gouraud
-%! title ({"BackFaceLighting", '"lit"', 'isonormals(...,"negate")'});
+%!  view (140, 20);
+%!  axis equal
+%!  hp = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
+%!              "BackFaceLighting", "lit", "VertexNormals", -vn);
+%!  hl = light ("Position", [1 0 .5]);
+%!  lighting gouraud
+%!  title ({"BackFaceLighting", '"lit"', 'isonormals(...,"negate")'});
 %!
 %! subplot (2, 3, 3);
-%! view (140, 20);
-%! axis equal
-%! hp = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
-%!             "BackFaceLighting", "unlit", "VertexNormals", -vn);
-%! hl = light ("Position", [1 0 .5]);
-%! lighting gouraud
-%! title ({"BackFaceLighting", '"unlit"', 'isonormals(...,"negate")'});
+%!  view (140, 20);
+%!  axis equal
+%!  hp = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
+%!              "BackFaceLighting", "unlit", "VertexNormals", -vn);
+%!  hl = light ("Position", [1 0 .5]);
+%!  lighting gouraud
+%!  title ({"BackFaceLighting", '"unlit"', 'isonormals(...,"negate")'});
 %!
 %! subplot (2, 3, 4);
-%! view (140, 20);
-%! axis equal
-%! hp = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
-%!             "BackFaceLighting", "reverselit", "VertexNormals", vn);
-%! hl = light ("Position", [1 0 .5]);
-%! lighting gouraud
-%! title ({"BackFaceLighting", '"reverselit"', "isonormals(...)"});
+%!  view (140, 20);
+%!  axis equal
+%!  hp = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
+%!              "BackFaceLighting", "reverselit", "VertexNormals", vn);
+%!  hl = light ("Position", [1 0 .5]);
+%!  lighting gouraud
+%!  title ({"BackFaceLighting", '"reverselit"', "isonormals(...)"});
 %!
 %! subplot (2, 3, 5);
-%! view (140, 20);
-%! axis equal
-%! hp = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
-%!             "BackFaceLighting", "lit", "VertexNormals", vn);
-%! hl = light ("Position", [1 0 .5]);
-%! lighting gouraud
-%! title ({"BackFaceLighting", '"lit"', "isonormals(...)"});
+%!  view (140, 20);
+%!  axis equal
+%!  hp = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
+%!              "BackFaceLighting", "lit", "VertexNormals", vn);
+%!  hl = light ("Position", [1 0 .5]);
+%!  lighting gouraud
+%!  title ({"BackFaceLighting", '"lit"', "isonormals(...)"});
 %!
 %! subplot (2, 3, 6);
-%! view (140, 20);
-%! axis equal
-%! hp = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
-%!             "BackFaceLighting", "unlit", "VertexNormals", vn);
-%! hl = light ("Position", [1 0 .5]);
-%! lighting gouraud
-%! title ({"BackFaceLighting", '"unlit"', "isonormals(...)"});
+%!  view (140, 20);
+%!  axis equal
+%!  hp = patch (fv, "FaceColor", "r", "EdgeColor", "none", ...
+%!              "BackFaceLighting", "unlit", "VertexNormals", vn);
+%!  hl = light ("Position", [1 0 .5]);
+%!  lighting gouraud
+%!  title ({"BackFaceLighting", '"unlit"', "isonormals(...)"});
 
 %!demo
 %! ## Colored patch
@@ -478,16 +505,17 @@ endfunction
 %! val = (x.^2 + y.^2 + z.^2);
 %!
 %! h_axes = axes ();
+%! view (3);
 %! fv = isosurface (x, y, z, val, .039, z);
 %! h_patch = patch (fv, "FaceColor", "flat", "EdgeColor", "none", ...
 %!                      "FaceLighting", "Gouraud");
 %! set (h_patch, "SpecularExponent", 15);
 %! isonormals (x, y, z, val, h_patch);
-%! title ("Colored patch");
 %! h_light = light ("Position", [-1 1 1]);
+%! view (3);
 %! axis tight
 %! axis equal
-%! view (3);
+%! title ("Colored patch");
 
 %!demo
 %! ## Colored mesh (patch)
@@ -499,20 +527,20 @@ endfunction
 %! fv = isosurface (x, y, z, val, .039, z);
 %! h_patch = patch (fv, "FaceColor", "w", "EdgeColor", "interp");
 %! isonormals (x, y, z, val, h_patch);
-%! title ("Colored mesh (patch)");
-%! h_light = light;
+%! h_light = light ();
 %! lighting gouraud
+%! view (3);
 %! axis tight;
 %! axis equal;
 %! box off;
-%! view (3);
+%! title ("Colored mesh (patch)");
 
 %!demo
 %! ## Colored mesh (surface)
 %! clf;
 %! h_mesh = mesh (peaks);
 %! title ("Colored mesh (surface)");
-%! h_light = light;
+%! h_light = light ();
 %! lighting gouraud
 
 %!demo
@@ -531,24 +559,24 @@ endfunction
 %! val = (x.^2 + y.^2 + z.^2);
 %!
 %! h_axes1 = subplot (1,2,1);
-%! fv = isosurface (x, y, z, val, .039);
-%! h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none");
-%! isonormals (x, y, z, val, h_patch);
-%! title ('"Style" = "infinite" (default)');
-%! h_light = light ("Position", [.3 0 .3]);
-%! lighting gouraud
-%! axis equal
-%! view (3);
+%!  fv = isosurface (x, y, z, val, .039);
+%!  h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none");
+%!  isonormals (x, y, z, val, h_patch);
+%!  title ('"Style" = "infinite" (default)');
+%!  h_light = light ("Position", [.3 0 .3]);
+%!  lighting gouraud
+%!  view (3);
+%!  axis equal
 %!
 %! h_axes2 = subplot (1,2,2);
-%! fv = isosurface (x, y, z, val, .039);
-%! h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none");
-%! isonormals (x, y, z, val, h_patch);
-%! title ('"Style" = "local"');
-%! h_light = light ("Style", "local", "Position", [.3 0 .3]);
-%! lighting gouraud
-%! axis equal
-%! view (3);
+%!  fv = isosurface (x, y, z, val, .039);
+%!  h_patch = patch (fv, "FaceColor", "r", "EdgeColor", "none");
+%!  isonormals (x, y, z, val, h_patch);
+%!  title ('"Style" = "local"');
+%!  h_light = light ("Style", "local", "Position", [.3 0 .3]);
+%!  lighting gouraud
+%!  view (3);
+%!  axis equal
 
 %!test
 %! hf = figure ("visible", "off");
@@ -564,7 +592,7 @@ endfunction
 
 %!test
 %! hf = figure ("visible", "off");
-%! ha = gca;
+%! ha = gca ();
 %! unwind_protect
 %!   h = light (ha, "Position", [1 2 3], "Color", "r");
 %!   assert (get (h, "Position"), [1 2 3]);
