@@ -1,20 +1,27 @@
-## Copyright (C) 2007-2017 David Bateman
+########################################################################
+##
+## Copyright (C) 2007-2024 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn {} {[@var{c}, @var{hg}] =} __contour__ (@dots{})
@@ -73,14 +80,36 @@ function [c, hg] = __contour__ (varargin)
     z1 = varargin{3};
     x1 = 1 : columns (z1);
     y1 = 1 : rows (z1);
+    if (! ismatrix (z1))
+      error ("__contour__: Z must be a 2-D matrix");
+    endif
   else
     x1 = varargin{3};
     y1 = varargin{4};
     z1 = varargin{5};
+    if (! ismatrix (z1) || ! ismatrix (x1) || ! ismatrix (y1))
+      error ("__contour__: X, Y, and Z must be matrices");
+    endif
+    if (isvector (x1))
+      if (columns (z1) != length (x1))
+        error ("__contour__: size of X must match number of columns in Z");
+      endif
+    else
+      if (! size_equal (x1, z1))
+        error ("__contour__: size of X and Z must match");
+      endif
+    endif
+    if (isvector (y1))
+      if (rows (z1) != length (y1))
+        error ("__contour__: size of Y must match number of rows in Z");
+      endif
+    else
+      if (! size_equal (y1, z1))
+        error ("__contour__: size of Y and Z must match");
+      endif
+    endif
   endif
-  if (! ismatrix (z1) || ! ismatrix (x1) || ! ismatrix (y1))
-    error ("__contour__: X, Y, and Z must be matrices");
-  endif
+
   if (length (varargin) == 4 || length (varargin) == 6)
     vn = varargin{end};
     vnauto = false;
@@ -117,7 +146,7 @@ function [c, hg] = __contour__ (varargin)
     [c, lev] = contourc (x1, y1, z1, lvl);
   endif
 
-  hg = hggroup ();
+  hg = hggroup ("__appdata__", struct ("__creator__", "__contour__"));
   opts = __add_datasource__ ("__countour__", hg, {"x", "y", "z"}, opts{:});
 
   addproperty ("xdata", hg, "data", x1);
@@ -168,6 +197,9 @@ function [c, hg] = __contour__ (varargin)
   addproperty ("linestyle", hg, "linelinestyle", linespec.linestyle);
   addproperty ("linewidth", hg, "linelinewidth", 0.5);
 
+  ## Matlab property just for compatibility (bug #60513).
+  addproperty ("facecolor", hg, "patchfacecolor", "none");
+
   ## Matlab property, although Octave does not implement it.
   addproperty ("hittestarea", hg, "radio", "on|{off}", "off");
 
@@ -357,7 +389,7 @@ function add_patch_children (hg)
           h = [h; __go_patch__(ca, "xdata", p(:,1), "ydata", p(:,2),
                                "zdata", clev * ones (rows (p),1),
                                "vertices", [p, clev * ones(rows(p),1)],
-                               "faces", 1:rows(p),
+                               "faces", 1:rows (p),
                                "facevertexcdata", clev, "facecolor", "none",
                                "cdata", clev, "edgecolor", lc,
                                "linestyle", ls, "linewidth", lw,
@@ -448,8 +480,7 @@ function update_data (h, ~, prop = "")
       else
         lvl = lvl(1) : lvs : lvl(2);
       endif
-      set (h, "levellist", lvl);
-      set (h, "levellistmode", "auto");
+      set (h, "levellist", lvl, "levellistmode", "auto");
     else
       z = get (h, "zdata");
       ## FIXME: The levels should be determined similarly to {x,y,z}ticks
